/* Generated by dbus-binding-tool; do not edit! */

#include <glib.h>
#include <dbus/dbus-glib.h>

G_BEGIN_DECLS

#ifndef _DBUS_GLIB_ASYNC_DATA_FREE
#define _DBUS_GLIB_ASYNC_DATA_FREE
static inline void
_dbus_glib_async_data_free (gpointer stuff)
{
	g_slice_free (DBusGAsyncData, stuff);
}
#endif

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_mate_SettingsDaemon
#define DBUS_GLIB_CLIENT_WRAPPERS_org_mate_SettingsDaemon

static inline gboolean
org_mate_SettingsDaemon_awake (DBusGProxy *proxy, GError **error)

{
  return dbus_g_proxy_call (proxy, "Awake", error, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_mate_SettingsDaemon_awake_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_mate_SettingsDaemon_awake_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_mate_SettingsDaemon_awake_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static inline DBusGProxyCall*
org_mate_SettingsDaemon_awake_async (DBusGProxy *proxy, org_mate_SettingsDaemon_awake_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_slice_new (DBusGAsyncData);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "Awake", org_mate_SettingsDaemon_awake_async_callback, stuff, _dbus_glib_async_data_free, G_TYPE_INVALID);
}
static inline gboolean
org_mate_SettingsDaemon_start (DBusGProxy *proxy, GError **error)

{
  return dbus_g_proxy_call (proxy, "Start", error, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_mate_SettingsDaemon_start_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_mate_SettingsDaemon_start_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_mate_SettingsDaemon_start_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static inline DBusGProxyCall*
org_mate_SettingsDaemon_start_async (DBusGProxy *proxy, org_mate_SettingsDaemon_start_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_slice_new (DBusGAsyncData);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "Start", org_mate_SettingsDaemon_start_async_callback, stuff, _dbus_glib_async_data_free, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_mate_SettingsDaemon */

G_END_DECLS
